#ifndef ALTITUDEPROFILEGRAPH_H
#define ALTITUDEPROFILEGRAPH_H

#include "AbstractChart.h"

#include <rx/columbus/ColumbusModel.h>

class AltitudeProfileGraphPrivate;

class AltitudeProfileGraph : public AbstractChart
{
    Q_OBJECT

public:
    explicit AltitudeProfileGraph(QWidget *parent = 0);

    ColumbusModel* model() const;

public slots:
    void setColumbusModel(ColumbusModel *model);

protected:
    void paintEvent(QPaintEvent *event);

private:
    AltitudeProfileGraphPrivate *d;
};

#endif // ALTITUDEPROFILEGRAPH_H
